@@ -1,7 +1,8 @@
 from django.conf.urls import patterns, include, url
 from django_url_alias.utils import aliased_urls
-from django.conf import settings
+from .settings import URL_ALIAS_ROOT_URLCONF
+
 
 urlpatterns = patterns('',
-    aliased_urls(settings.URL_ALIAS_ROOT_URLCONF),
+    aliased_urls(URL_ALIAS_ROOT_URLCONF),
 )
